<div class="card w-full rounded-lg border bg-base-300 shadow dark:border-gray-600 border-gray-100">
    <div class="card-body">
        <div class="card-title text-lg font-semibold">
            <span class="font-extrabold">Growth Plan -</span>  Usage-Based <i class="fa fa-gauge-high -ms-1"></i> Pricing
        </div>

        <hr class="my-3" />

        <!-- Invoices Section -->
        <div tabindex="0" class="collapse collapse-arrow border border-base-300 bg-base-100 rounded-box">
            <input type="checkbox" class="peer" />
            <div class="collapse-title text-xl font-medium">
                Invoices
            </div>
            <div class="collapse-content">
                <table class="table table-auto w-full mt-2">
                    <thead>
                    <tr>
                        <th class="text-left">Quantity</th>
                        <th class="text-left">Unit Price</th>
                    </tr>
                    </thead>
                    <tbody>
                    <tr>
                        <td>First 80 invoices</td>
                        <td>Included for free</td>
                    </tr>
                    <tr>
                        <td>Next 170 invoices</td>
                        <td>£0.04/invoice</td>
                    </tr>
                    <tr>
                        <td>Greater than 250 invoices</td>
                        <td>£0.03/invoice</td>
                    </tr>
                    </tbody>
                </table>
            </div>
        </div>

        <!-- Recurring Invoices Section -->
        <div tabindex="0" class="collapse collapse-arrow border border-base-300 bg-base-100 rounded-box mt-4">
            <input type="checkbox" class="peer" />
            <div class="collapse-title text-xl font-medium">
                Recurring Invoices
            </div>
            <div class="collapse-content">
                <table class="table table-auto w-full mt-2">
                    <thead>
                    <tr>
                        <th class="text-left">Quantity</th>
                        <th class="text-left">Unit Price</th>
                    </tr>
                    </thead>
                    <tbody>
                    <tr>
                        <td>First 100 invocations</td>
                        <td>Included for free</td>
                    </tr>
                    <tr>
                        <td>Next 400 invocations</td>
                        <td>£0.07/invocation</td>
                    </tr>
                    <tr>
                        <td>Greater than 500 invocations</td>
                        <td>£0.04/invocation</td>
                    </tr>
                    </tbody>
                </table>
            </div>
        </div>

        <!-- Invoice Reminders Section (Only Growth Plan) -->
        <div tabindex="0" class="collapse collapse-arrow border border-base-300 bg-base-100 rounded-box mt-4">
            <input type="checkbox" class="peer" />
            <div class="collapse-title text-xl font-medium">
                Invoice Reminders
            </div>
            <div class="collapse-content">
                <table class="table table-auto w-full mt-2">
                    <thead>
                    <tr>
                        <th class="text-left">Quantity</th>
                        <th class="text-left">Unit Price</th>
                    </tr>
                    </thead>
                    <tbody>
                    <tr>
                        <td>First 400 invocations</td>
                        <td>Included for free</td>
                    </tr>
                    <tr>
                        <td>Next 600 invocations</td>
                        <td>£0.02/invocation</td>
                    </tr>
                    <tr>
                        <td>Greater than 1000 invocations</td>
                        <td>£0.01/invocation</td>
                    </tr>
                    </tbody>
                </table>
            </div>
        </div>

        <!-- Advanced Onboarding Section (Only Growth Plan) -->
        <div tabindex="0" class="collapse collapse-arrow border border-base-300 bg-base-100 rounded-box mt-4">
            <input type="checkbox" class="peer" />
            <div class="collapse-title text-xl font-medium">
                Advanced Onboarding
            </div>
            <div class="collapse-content">
                <table class="table table-auto w-full mt-2">
                    <thead>
                    <tr>
                        <th class="text-left">Quantity</th>
                        <th class="text-left">Unit Price</th>
                    </tr>
                    </thead>
                    <tbody>
                    <tr>
                        <td>First 5 customers</td>
                        <td>Included for free</td>
                    </tr>
                    <tr>
                        <td>Next 20 customers</td>
                        <td>£0.10/customer</td>
                    </tr>
                    <tr>
                        <td>Greater than 25 customers</td>
                        <td>£0.08/customer</td>
                    </tr>
                    </tbody>
                </table>
            </div>
        </div>
    </div>
</div>
