{% extends base|default:"base/base.html" %}
{% block content %}
    <div class="grid grid-cols-8 gap-4">
        <div class="card p-4 col-span-2">
            <ul class="menu w-full min-h-full gap-y-1"
                hx-boost="true"
                hx-target='div[data-hx-swap="content"]'
                hx-swap="innerHTML"
                hx-vals='{"on_main": "True"}'>
                <li>
                    <a href="{% url 'core:settings:dashboard with page' page='profile' %}"
                       hx-replace-url="{% url 'core:settings:dashboard with page' page='profile' %}">
                        <i class="fa fa-solid fa-user"></i>
                        Public Profile
                    </a>
                </li>
                <li>
                    <a href="{% url 'core:settings:dashboard with page' page='account' %}"
                       hx-replace-url="{% url 'core:settings:dashboard with page' page='account' %}">
                        <i class="fa fa-solid fa-gear"></i>
                        Account
                    </a>
                </li>
                <div class="divider"></div>
                <h2 class="pl-3 text-neutral-content">Invoice Preferences</h2>
                <li>
                    <a href="{% url 'core:settings:dashboard with page' page='email_templates' %}"
                       hx-replace-url="{% url 'core:settings:dashboard with page' page='email_templates' %}">
                        <i class="fa fa-solid fa-envelope"></i>
                        Email Templates
                    </a>
                </li>
                <li>
                    <a href="{% url 'core:settings:dashboard with page' page='account_defaults' %}"
                       hx-replace-url="{% url 'core:settings:dashboard with page' page='account_defaults' %}">
                        <i class="fa fa-solid fa-toolbox"></i>
                        Account defaults
                    </a>
                </li>
                <div class="divider"></div>
                <h2 class="pl-3 text-neutral-content">Access</h2>
                <li>
                    <a href="{% url 'core:settings:dashboard with page' page='api_keys' %}"
                       hx-replace-url="{% url 'core:settings:dashboard with page' page='api_keys' %}">
                        <i class="fa fa-solid fa-code"></i>
                        API Keys
                    </a>
                </li>
                <li>
                    <a href="{% url 'core:settings:dashboard with page' page='account_security' %}"
                       hx-replace-url="{% url 'core:settings:dashboard with page' page='account_security' %}">
                        <i class="fa fa-solid fa-shield"></i>
                        Account Security
                    </a>
                </li>
            </ul>
        </div>
        <div class="col-span-6" data-hx-swap="content">
            {% if page_template %}
                {% include page_template %}
            {% endif %}
        </div>
    </div>
{% endblock content %}
