<li class="py-4">
    <div class="flex items-center space-x-4">
        <div class="flex-shrink-0">
            {% if "12"|random == "1" %}
                <i class="fa-solid fa-desktop dark:text-white"></i>
            {% else %}
                <i class="fa-solid fa-mobile-screen-button dark:text-white"></i>
            {% endif %}
        </div>
        <div class="min-w-0 flex-1">
            <p class="truncate text-base font-semibold text-gray-900 dark:text-white">Country 1.1.1.1</p>
            <p class="truncate text-sm font-normal text-gray-500 dark:text-gray-400">Chrome on windows</p>
        </div>
        <div class="inline-flex items-center">
            <button class="btn btn-outline btn-error">Revoke</button>
        </div>
    </div>
</li>
