{% load static %}
{% component "profile_picture" swap_oob="small" image_type="small" extra_classes="max-w-12 max-h-12 w-12 h-12 avatar-img-ring" url=users_profile_picture %}
{% component "profile_picture" swap_oob="change_modal" image_type="change_modal" extra_classes="max-w-44 max-h-44 w-44 h-44 rounded-full ring ring-primary ring-offset-base-100 ring-offset-2" url=users_profile_picture %}
{% component "messages_list" %}
