{% load static %}
{% load render_bundle from webpack_loader %}
{% load tz_detect %}
<head>
    <meta charset="UTF-8" />
    <meta name="viewport" content="width=device-width, initial-scale=1.0" />
    <title>My Finances</title>
    <link rel="shortcut icon"
          type="image/png"
          href="{% static 'favicon/android-chrome-512x512.png' %}">
    <!-- Fonts -->
    <link href="https://fonts.googleapis.com/css2?family=Inter:wght@400;500;600;700;800&display=swap"
          rel="stylesheet" />
    <link rel="stylesheet"
          href="https://fonts.googleapis.com/css?family=Agbalumo">
    <link rel="stylesheet"
          href="https://fonts.googleapis.com/css?family=Montserrat">
    {% if import_method == "public_cdn" %}
        <!-- JQuery -->
        <script src="https://code.jquery.com/jquery-3.7.0.min.js"
                integrity="sha256-2Pmvv0kuTBOenSvLm6bvfBSSHrUJ+3A7x6P5Ebd07/g="
                crossorigin="anonymous"></script>
        <!-- Tailwind & DaisyUI -->
        <link rel="stylesheet" href="{% static 'src/output.css' %}?v={{ version }}">
        {#    <script src="https://cdn.tailwindcss.com"></script>#}
        <!-- FontAwesome -->
        <link rel="stylesheet"
              href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.1.1/css/all.min.css" />
        <!-- HyperScript -->
        {#    <script src="https://unpkg.com/hyperscript.org@0.9.12"></script>#}
        <!-- AlpineJS -->
        <script defer
                src="https://cdn.jsdelivr.net/npm/alpinejs@3.x.x/dist/cdn.min.js"></script>
        {#    <script src="{% static 'js/c/init-alpine.js' %}"></script>#}
        <!-- SimpleMDE -->
        {#        <script src="https://cdn.jsdelivr.net/simplemde/latest/simplemde.min.js"></script>#}
        {#
        <link rel="stylesheet" href="https://cdn.jsdelivr.net/simplemde/latest/simplemde.min.css">#}
        <!-- Markdown -->
        {#        <script type="module" src="https://md-block.verou.me/md-block.js"></script>#}
        {# Not in use at the moment MAY USE LATER ^^ #}
        <!-- HTMX -->
        <script src="https://unpkg.com/htmx.org@1.9.4"
                integrity="sha384-zUfuhFKKZCbHTY6aRR46gxiqszMk5tcHjsVFxnUo8VMus4kHGVdIYVbOYYNlKmHV"
                crossorigin="anonymous"></script>
        <script src="https://unpkg.com/htmx.org/dist/ext/multi-swap.js"></script>
        {#        <script src="https://unpkg.com/htmx.org/dist/ext/response-targets.js"></script>#}
        <script src="https://unpkg.com/hyperscript.org@0.9.12"></script>
    {% else %}
        {#        <script defer type="text/javascript" src="{% static "js/c/init.js" %}"></script>#}
        {#        <script defer type="text/javascript" src="{% static "js/c/htmx.js" %}"></script>#}
        {#        <script defer type="text/javascript" src="{% static "js/c/font_awesome.js" %}"></script>#}
        {#        {% render_bundle 'all' 'js' %}#}
        {% render_bundle 'init' 'js' %}
        {% render_bundle 'tableify' 'js' %}
        {% render_bundle 'htmx' 'js' %}
        {% render_bundle 'font_awesome' 'js' %}
        <!-- Tailwind & DaisyUI -->
        <link rel="stylesheet" href="{% static 'src/output.css' %}?v={{ version }}">
    {% endif %}
    {% render_bundle 'receipt_downloads' 'js' %}
    {{ analytics|safe }}
    {% tz_detect %}
    {#    <script>#}
    {#        document.body.addEventListener('htmx:configRequest', (event) => {#}
    {#            event.detail.headers['X-CSRFToken'] = '{{ csrf_token }}';#}
    {#        })#}
    {#    </script>#}
</head>
