{% load has_module safe_url from feature_enabled %}
{% has_module "billing" as billing_enabled %}
<div data-layout="icon_dropdown_items">
    <li hx-boost="true">
        <a {% if request.resolver_match.view_name == "settings:dashboard" %}class="active btn-disabled"{% endif %}
           href="{% url 'core:settings:dashboard' %}">
            <i class="fa fa-solid fa-cog"></i>
            Settings
        </a>
    </li>
    <li hx-boost="true">
        <a {% if request.resolver_match.view_name == "core:teams:dashboard" %}class="active btn-disabled"{% endif %}
           href="{% url "core:teams:dashboard" %}">
            <i class="fa fa-solid fa-users"></i>
            Manage Team
        </a>
    </li>
    {#    {% if billing_enabled %}#}
    <li hx-boost="true">
        <a {% if request.resolver_match.view_name == "billing:dashboard" %}class="active btn-disabled"{% endif %}
           href="{% safe_url 'billing:dashboard' %}">
            <i class="fa fa-coins"></i>
            Billing Dashboard
        </a>
    </li>
    {#    {% endif %}#}
    <li>
        <label for="logout_modal">
            <i class="fa fa-solid fa-right-from-bracket"></i>
            Logout
        </label>
    </li>
    <div class="divider"></div>
    {% if request.user.is_superuser and request.user.is_staff %}
        <li>
            <a tabindex="-1" class="dropdown-item text text-sm mt-1" href="/admin/">Go to admin dashboard</a>
        </li>
    {% endif %}
    <li>
        <span>Current Version: {{ version }}</span>
    </li>
    {% if git_version and git_version != "prod" %}
        <li>
            <span class="text-center">{{ git_version | slice:7 }}</span>
        </li>
    {% endif %}
</div>
