{% extends 'core/auth/auth.html' %}
{% load static %}
{% block image %}
    {% static 'img/choose.svg' %}
{% endblock image %}
{% block title %}
    Create an account
{% endblock title %}
{% block content %}
    <a href="{% url 'core:auth:login create_account manual' %}"
       class="btn-large-card">Create with manual details</a>
    {% if github_enabled %}
        <a href="{% url 'social:begin' 'github' %}" class="btn-large-card">
            <i class="fa-brands fa-github mr-2"></i>
            Create with github
        </a>
    {% endif %}
    {% if google_enabled %}
        <a href="{% url 'social:begin' 'google-oauth2' %}"
           class="btn-large-card">
            <i class="fa-brands fa-google mr-2 text-orange-500"></i>
            Create with google
        </a>
    {% endif %}
{% endblock %}
